==> pkg_onecore-1.0.11.zip: admin/com_onecore/site/src/View/Events/HtmlView.php <==
<?php

/**
 * @package     Comdev.Component
 * @subpackage  com_onecore
 *
 * @copyright   (C) 2026 Comdev. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Comdev\Component\Onecore\Site\View\Events;

use Comdev\Component\Onecore\Site\Helper\ContentHelper;
use Comdev\Component\Onecore\Site\Helper\CustomFieldsHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\MVC\View\GenericDataException;
use Joomla\Database\ParameterType;

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 * HTML Events View class for the OneCore component
 *
 * @since  1.0.0
 */
class HtmlView extends BaseHtmlView
{
	/**
	 * An array of items
	 *
	 * @var  array
	 */
	protected $items;

	/**
	 * The pagination object
	 *
	 * @var  \Joomla\CMS\Pagination\Pagination
	 */
	protected $pagination;

	/**
	 * The model state
	 *
	 * @var   \Joomla\Registry\Registry
	 */
	protected $state;

	/**
	 * The page parameters
	 *
	 * @var    \Joomla\Registry\Registry|null
	 */
	protected $params = null;

	/**
	 * All events with locations for map (regardless of pagination)
	 *
	 * @var  array
	 */
	protected $allMapItems = [];

	/**
	 * Execute and display a template script.
	 *
	 * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
	 *
	 * @return  void
	 */
	public function display($tpl = null)
	{
		/** @var \Comdev\Component\Onecore\Site\Model\EventsModel $model */
		$model = $this->getModel('Events');
		
		$this->items = $model->getItems();
		$this->pagination = $model->getPagination();
		$this->state = $model->getState();
		$this->params = $this->state->get('params');

		// Process items - add images and categories
		foreach ($this->items as &$item) {
			// Get first image
			$item->image = ContentHelper::getFirstImage($item->images ?? '');
			
			// Get all categories for this event
			$item->categories = ContentHelper::getEventCategories($item->id);
		}

		// Attach custom fields for list context ("items") in both positions
		$ids = array_map(static fn($it) => (int) ($it->id ?? 0), $this->items ?: []);
		$ids = array_values(array_filter($ids));

		if (!empty($ids)) {
			// Check if custom fields should be filtered by searchable setting
			$app = Factory::getApplication();
			$input = $app->getInput();
			$showCustomFields = (int) $input->get('show_custom_fields', $this->params->get('show_custom_fields', 1), 'int');
			$onlySearchable = ($showCustomFields === 1) ? true : false;
			
			if ($showCustomFields === 0) {
				$fieldsUnderTitle = [];
				$fieldsUnderIntro = [];
			} else {
				$fieldsUnderTitle = CustomFieldsHelper::getFieldsForEventIds($ids, 'items', 'under_title', $onlySearchable);
				$fieldsUnderIntro = CustomFieldsHelper::getFieldsForEventIds($ids, 'items', 'under_intro', $onlySearchable);
			}

			foreach ($this->items as &$item) {
				$eid = (int) ($item->id ?? 0);
				$item->customfields_under_title = $fieldsUnderTitle[$eid] ?? [];
				$item->customfields_under_intro = $fieldsUnderIntro[$eid] ?? [];
			}
		}

		// Check for errors.
		if (\count($errors = $model->getErrors())) {
			throw new GenericDataException(implode("\n", $errors), 500);
		}

		// Get all events with locations for map (regardless of pagination)
		$this->allMapItems = $this->getAllEventsWithLocations($model);

		// Always use 'default' layout
		$this->setLayout('default');

		parent::display($tpl);
	}

	/**
	 * Get all events with locations for map display (regardless of pagination)
	 *
	 * @param   \Comdev\Component\Onecore\Site\Model\EventsModel  $model  The events model
	 *
	 * @return  array  Array of events with latitude and longitude
	 *
	 * @since   1.0.0
	 */
	protected function getAllEventsWithLocations($model): array
	{
		$db = Factory::getDbo();
		$query = $db->createQuery();

		// Get current state filters
		$state = $model->getState();
		$categoryId = $state->get('filter.category_id');
		$categories = $state->get('filter.categories', []);
		$search = $state->get('filter.search');
		$dateFrom = $state->get('filter.date_from');
		$dateTo = $state->get('filter.date_to');
		$featured = $state->get('filter.featured');
		$published = $state->get('filter.published', 1);
		$customFieldsFilters = $state->get('filter.custom_fields', []);

		// Build query similar to EventsModel but without pagination
		$query->select([
			$db->quoteName('a.id'),
			$db->quoteName('a.title'),
			$db->quoteName('a.alias'),
			$db->quoteName('a.event_start'),
			$db->quoteName('a.featured'),
			$db->quoteName('addr.latitude', 'latitude'),
			$db->quoteName('addr.longitude', 'longitude'),
		])
			->from($db->quoteName('#__one_events', 'a'))
			->leftJoin($db->quoteName('#__one_event_addresses', 'addr'), $db->quoteName('addr.event_id') . ' = ' . $db->quoteName('a.id'))
			->where($db->quoteName('a.published') . ' = :published')
			->where($db->quoteName('addr.latitude') . ' IS NOT NULL')
			->where($db->quoteName('addr.longitude') . ' IS NOT NULL')
			->where($db->quoteName('addr.latitude') . ' != ' . $db->quote(''))
			->where($db->quoteName('addr.longitude') . ' != ' . $db->quote(''))
			->bind(':published', $published, ParameterType::INTEGER);

		// Apply same filters as in EventsModel
		if (is_numeric($categoryId)) {
			$query->where($db->quoteName('a.id') . ' IN (
				SELECT ' . $db->quoteName('event_id') . ' 
				FROM ' . $db->quoteName('#__one_event_categories') . ' 
				WHERE ' . $db->quoteName('category_id') . ' = :category_id
			)')
				->bind(':category_id', $categoryId, ParameterType::INTEGER);
		}

		if (!empty($categories) && is_array($categories)) {
			$categories = array_filter(array_map('intval', $categories));
			if (!empty($categories)) {
				$query->where($db->quoteName('a.id') . ' IN (
					SELECT ' . $db->quoteName('event_id') . ' 
					FROM ' . $db->quoteName('#__one_event_categories') . ' 
					WHERE ' . $db->quoteName('category_id') . ' IN (' . implode(',', $categories) . ')
				)');
			}
		}

		if (!empty($search)) {
			$searchTerm = '%' . $db->escape($search, true) . '%';
			$query->where('(' . $db->quoteName('a.title') . ' LIKE :search1 
				OR ' . $db->quoteName('a.description') . ' LIKE :search2)')
				->bind(':search1', $searchTerm)
				->bind(':search2', $searchTerm);
		}

		if (!empty($dateFrom)) {
			$query->where($db->quoteName('a.event_start') . ' >= :date_from')
				->bind(':date_from', $dateFrom);
		}

		if (!empty($dateTo)) {
			$query->where($db->quoteName('a.event_end') . ' <= :date_to')
				->bind(':date_to', $dateTo);
		}

		// Featured filter
		if ($featured == 1) {
			$query->where($db->quoteName('a.featured') . ' = 1');
		}

		// Filter by access level
		$user = Factory::getUser();
		if (!$user->authorise('core.admin')) {
			$groups = $user->getAuthorisedViewLevels();
			$query->whereIn($db->quoteName('a.access'), $groups);
		}

		// Apply custom fields filters (simplified version - same logic as EventsModel)
		if (!empty($customFieldsFilters) && is_array($customFieldsFilters)) {
			$fieldIds = array_keys($customFieldsFilters);
			$fieldIds = array_filter(array_map('intval', $fieldIds));
			$fieldTypes = [];
			if (!empty($fieldIds)) {
				$typeQuery = $db->createQuery()
					->select([$db->quoteName('id'), $db->quoteName('type')])
					->from($db->quoteName('#__one_customfields'))
					->whereIn($db->quoteName('id'), $fieldIds);
				$db->setQuery($typeQuery);
				try {
					$typeResults = $db->loadObjectList();
					foreach ($typeResults as $typeResult) {
						$fieldTypes[(int) $typeResult->id] = (string) $typeResult->type;
					}
				} catch (\Exception $e) {
					// Ignore errors
				}
			}

			foreach ($customFieldsFilters as $fieldId => $fieldValue) {
				$fieldId = (int) $fieldId;
				if ($fieldId <= 0) {
					continue;
				}

				$fieldType = $fieldTypes[$fieldId] ?? 'input';

				$subQuery = $db->createQuery()
					->select('1')
					->from($db->quoteName('#__one_customfield_values', 'cfv'))
					->innerJoin(
						$db->quoteName('#__one_customfields', 'cff'),
						$db->quoteName('cff.id') . ' = ' . $db->quoteName('cfv.field_id')
					)
					->where($db->quoteName('cfv.event_id') . ' = ' . $db->quoteName('a.id'))
					->where($db->quoteName('cfv.field_id') . ' = :cf_field_id_' . $fieldId)
					->where($db->quoteName('cff.published') . ' = 1')
					->where($db->quoteName('cff.searchable') . ' = 1');

				if (is_array($fieldValue)) {
					$fieldValue = array_filter(array_map('trim', $fieldValue));
					if (!empty($fieldValue)) {
						if ($fieldType === 'select') {
							$subQuery->whereIn($db->quoteName('cfv.value'), $fieldValue);
						} else {
							$likeConditions = [];
							foreach ($fieldValue as $idx => $val) {
								$paramName = ':cf_value_' . $fieldId . '_' . $idx;
								$likeConditions[] = $db->quoteName('cfv.value') . ' LIKE ' . $paramName;
								$val = (string) trim($val);
								$searchValue = '%' . $val . '%';
								$query->bind($paramName, $searchValue, ParameterType::STRING);
							}
							if (!empty($likeConditions)) {
								$subQuery->where('(' . implode(' OR ', $likeConditions) . ')');
							}
						}
						$query->where('EXISTS (' . (string) $subQuery . ')');
						$fieldIdParam = ':cf_field_id_' . $fieldId;
						$query->bind($fieldIdParam, $fieldId, ParameterType::INTEGER);
					}
				} else {
					$fieldValue = trim($fieldValue);
					if (!empty($fieldValue)) {
						if ($fieldType === 'select') {
							$valueParam = ':cf_value_' . $fieldId;
							$subQuery->where($db->quoteName('cfv.value') . ' = ' . $valueParam);
							$query->bind($valueParam, $fieldValue);
						} else {
							$valueParam = ':cf_value_' . $fieldId;
							$subQuery->where($db->quoteName('cfv.value') . ' LIKE ' . $valueParam);
							$fieldValue = (string) trim($fieldValue);
							$searchValue = '%' . $fieldValue . '%';
							$query->bind($valueParam, $searchValue, ParameterType::STRING);
						}
						$query->where('EXISTS (' . (string) $subQuery . ')');
						$fieldIdParam = ':cf_field_id_' . $fieldId;
						$query->bind($fieldIdParam, $fieldId, ParameterType::INTEGER);
					}
				}
			}
		}

		$db->setQuery($query);

		try {
			return $db->loadObjectList() ?: [];
		} catch (\Exception $e) {
			return [];
		}
	}
}

==> pkg_onecore-1.0.19.zip: admin/com_onecore/site/src/View/Events/HtmlView.php <==
<?php

/**
 * @package     Comdev.Component
 * @subpackage  com_onecore
 *
 * @copyright   (C) 2026 Comdev. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Comdev\Component\Onecore\Site\View\Events;

use Comdev\Component\Onecore\Site\Helper\ContentHelper;
use Comdev\Component\Onecore\Site\Helper\CustomFieldsHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\MVC\View\GenericDataException;
use Joomla\Database\ParameterType;

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 * HTML Events View class for the OneCore component
 *
 * @since  1.0.0
 */
class HtmlView extends BaseHtmlView
{
	/**
	 * An array of items
	 *
	 * @var  array
	 */
	protected $items;

	/**
	 * The pagination object
	 *
	 * @var  \Joomla\CMS\Pagination\Pagination
	 */
	protected $pagination;

	/**
	 * The model state
	 *
	 * @var   \Joomla\Registry\Registry
	 */
	protected $state;

	/**
	 * The page parameters
	 *
	 * @var    \Joomla\Registry\Registry|null
	 */
	protected $params = null;

	/**
	 * All events with locations for map (regardless of pagination)
	 *
	 * @var  array
	 */
	protected $allMapItems = [];

	/**
	 * Execute and display a template script.
	 *
	 * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
	 *
	 * @return  void
	 */
	public function display($tpl = null)
	{
		/** @var \Comdev\Component\Onecore\Site\Model\EventsModel $model */
		$model = $this->getModel('Events');
		
		$this->items = $model->getItems();
		$this->pagination = $model->getPagination();
		$this->state = $model->getState();
		$this->params = $this->state->get('params');

		// Process items - add images and categories
		foreach ($this->items as &$item) {
			// Get first image
			$item->image = ContentHelper::getFirstImage($item->images ?? '');
			
			// Get all categories for this event
			$item->categories = ContentHelper::getEventCategories($item->id);
		}

		// Attach custom fields for list context ("items") in both positions
		$ids = array_map(static fn($it) => (int) ($it->id ?? 0), $this->items ?: []);
		$ids = array_values(array_filter($ids));

		if (!empty($ids)) {
			// Check if custom fields should be filtered by searchable setting
			$app = Factory::getApplication();
			$input = $app->getInput();
			$showCustomFields = (int) $input->get('show_custom_fields', $this->params->get('show_custom_fields', 1), 'int');
			$onlySearchable = ($showCustomFields === 1) ? true : false;
			
			if ($showCustomFields === 0) {
				$fieldsUnderTitle = [];
				$fieldsUnderIntro = [];
			} else {
				$fieldsUnderTitle = CustomFieldsHelper::getFieldsForEventIds($ids, 'items', 'under_title', $onlySearchable);
				$fieldsUnderIntro = CustomFieldsHelper::getFieldsForEventIds($ids, 'items', 'under_intro', $onlySearchable);
			}

			foreach ($this->items as &$item) {
				$eid = (int) ($item->id ?? 0);
				$item->customfields_under_title = $fieldsUnderTitle[$eid] ?? [];
				$item->customfields_under_intro = $fieldsUnderIntro[$eid] ?? [];
			}
		}

		// Check for errors.
		if (\count($errors = $model->getErrors())) {
			throw new GenericDataException(implode("\n", $errors), 500);
		}

		// Get all events with locations for map (regardless of pagination)
		$this->allMapItems = $this->getAllEventsWithLocations($model);

		// Always use 'default' layout
		$this->setLayout('default');

		$wa = $this->getDocument()->getWebAssetManager();
		// CSS: load from component folder so it works when /media/com_onecore/ has no copy
		$wa->registerAndUseStyle('com_onecore.event', 'components/com_onecore/assets/css/event.css')
			->registerAndUseStyle('com_onecore.events', 'components/com_onecore/assets/css/events.css');
		$wa->registerScript('com_onecore.feather', 'https://cdn.jsdelivr.net/npm/feather-icons/dist/feather.min.js', [], []);
		$wa->registerScript('com_onecore.feather-init', 'components/com_onecore/assets/js/feather-init.js', ['dependencies' => ['com_onecore.feather']], []);
		$wa->useScript('com_onecore.feather')->useScript('com_onecore.feather-init');

		parent::display($tpl);
	}

	/**
	 * Get all events with locations for map display (regardless of pagination)
	 *
	 * @param   \Comdev\Component\Onecore\Site\Model\EventsModel  $model  The events model
	 *
	 * @return  array  Array of events with latitude and longitude
	 *
	 * @since   1.0.0
	 */
	protected function getAllEventsWithLocations($model): array
	{
		$db = Factory::getDbo();
		$query = $db->createQuery();

		// Get current state filters
		$state = $model->getState();
		$categoryId = $state->get('filter.category_id');
		$categories = $state->get('filter.categories', []);
		$search = $state->get('filter.search');
		$dateFrom = $state->get('filter.date_from');
		$dateTo = $state->get('filter.date_to');
		$featured = $state->get('filter.featured');
		$published = $state->get('filter.published', 1);
		$customFieldsFilters = $state->get('filter.custom_fields', []);

		// Build query similar to EventsModel but without pagination
		$query->select([
			$db->quoteName('a.id'),
			$db->quoteName('a.title'),
			$db->quoteName('a.alias'),
			$db->quoteName('a.event_start'),
			$db->quoteName('a.featured'),
			$db->quoteName('addr.latitude', 'latitude'),
			$db->quoteName('addr.longitude', 'longitude'),
		])
			->from($db->quoteName('#__one_events', 'a'))
			->leftJoin($db->quoteName('#__one_event_addresses', 'addr'), $db->quoteName('addr.event_id') . ' = ' . $db->quoteName('a.id'))
			->where($db->quoteName('a.published') . ' = :published')
			->where($db->quoteName('addr.latitude') . ' IS NOT NULL')
			->where($db->quoteName('addr.longitude') . ' IS NOT NULL')
			->where($db->quoteName('addr.latitude') . ' != ' . $db->quote(''))
			->where($db->quoteName('addr.longitude') . ' != ' . $db->quote(''))
			->bind(':published', $published, ParameterType::INTEGER);

		// Apply same filters as in EventsModel
		if (is_numeric($categoryId)) {
			$query->where($db->quoteName('a.id') . ' IN (
				SELECT ' . $db->quoteName('event_id') . ' 
				FROM ' . $db->quoteName('#__one_event_categories') . ' 
				WHERE ' . $db->quoteName('category_id') . ' = :category_id
			)')
				->bind(':category_id', $categoryId, ParameterType::INTEGER);
		}

		if (!empty($categories) && is_array($categories)) {
			$categories = array_filter(array_map('intval', $categories));
			if (!empty($categories)) {
				$query->where($db->quoteName('a.id') . ' IN (
					SELECT ' . $db->quoteName('event_id') . ' 
					FROM ' . $db->quoteName('#__one_event_categories') . ' 
					WHERE ' . $db->quoteName('category_id') . ' IN (' . implode(',', $categories) . ')
				)');
			}
		}

		if (!empty($search)) {
			$searchTerm = '%' . $db->escape($search, true) . '%';
			$query->where('(' . $db->quoteName('a.title') . ' LIKE :search1 
				OR ' . $db->quoteName('a.description') . ' LIKE :search2)')
				->bind(':search1', $searchTerm)
				->bind(':search2', $searchTerm);
		}

		if (!empty($dateFrom)) {
			$query->where($db->quoteName('a.event_start') . ' >= :date_from')
				->bind(':date_from', $dateFrom);
		}

		if (!empty($dateTo)) {
			$query->where($db->quoteName('a.event_end') . ' <= :date_to')
				->bind(':date_to', $dateTo);
		}

		// Featured filter
		if ($featured == 1) {
			$query->where($db->quoteName('a.featured') . ' = 1');
		}

		// Filter by access level
		$user = Factory::getUser();
		if (!$user->authorise('core.admin')) {
			$groups = $user->getAuthorisedViewLevels();
			$query->whereIn($db->quoteName('a.access'), $groups);
		}

		// Apply custom fields filters (simplified version - same logic as EventsModel)
		if (!empty($customFieldsFilters) && is_array($customFieldsFilters)) {
			$fieldIds = array_keys($customFieldsFilters);
			$fieldIds = array_filter(array_map('intval', $fieldIds));
			$fieldTypes = [];
			if (!empty($fieldIds)) {
				$typeQuery = $db->createQuery()
					->select([$db->quoteName('id'), $db->quoteName('type')])
					->from($db->quoteName('#__one_customfields'))
					->whereIn($db->quoteName('id'), $fieldIds);
				$db->setQuery($typeQuery);
				try {
					$typeResults = $db->loadObjectList();
					foreach ($typeResults as $typeResult) {
						$fieldTypes[(int) $typeResult->id] = (string) $typeResult->type;
					}
				} catch (\Exception $e) {
					// Ignore errors
				}
			}

			foreach ($customFieldsFilters as $fieldId => $fieldValue) {
				$fieldId = (int) $fieldId;
				if ($fieldId <= 0) {
					continue;
				}

				$fieldType = $fieldTypes[$fieldId] ?? 'input';

				$subQuery = $db->createQuery()
					->select('1')
					->from($db->quoteName('#__one_customfield_values', 'cfv'))
					->innerJoin(
						$db->quoteName('#__one_customfields', 'cff'),
						$db->quoteName('cff.id') . ' = ' . $db->quoteName('cfv.field_id')
					)
					->where($db->quoteName('cfv.event_id') . ' = ' . $db->quoteName('a.id'))
					->where($db->quoteName('cfv.field_id') . ' = :cf_field_id_' . $fieldId)
					->where($db->quoteName('cff.published') . ' = 1')
					->where($db->quoteName('cff.searchable') . ' = 1');

				if (is_array($fieldValue)) {
					$fieldValue = array_filter(array_map('trim', $fieldValue));
					if (!empty($fieldValue)) {
						if ($fieldType === 'select') {
							$subQuery->whereIn($db->quoteName('cfv.value'), $fieldValue);
						} else {
							$likeConditions = [];
							foreach ($fieldValue as $idx => $val) {
								$paramName = ':cf_value_' . $fieldId . '_' . $idx;
								$likeConditions[] = $db->quoteName('cfv.value') . ' LIKE ' . $paramName;
								$val = (string) trim($val);
								$searchValue = '%' . $val . '%';
								$query->bind($paramName, $searchValue, ParameterType::STRING);
							}
							if (!empty($likeConditions)) {
								$subQuery->where('(' . implode(' OR ', $likeConditions) . ')');
							}
						}
						$query->where('EXISTS (' . (string) $subQuery . ')');
						$fieldIdParam = ':cf_field_id_' . $fieldId;
						$query->bind($fieldIdParam, $fieldId, ParameterType::INTEGER);
					}
				} else {
					$fieldValue = trim($fieldValue);
					if (!empty($fieldValue)) {
						if ($fieldType === 'select') {
							$valueParam = ':cf_value_' . $fieldId;
							$subQuery->where($db->quoteName('cfv.value') . ' = ' . $valueParam);
							$query->bind($valueParam, $fieldValue);
						} else {
							$valueParam = ':cf_value_' . $fieldId;
							$subQuery->where($db->quoteName('cfv.value') . ' LIKE ' . $valueParam);
							$fieldValue = (string) trim($fieldValue);
							$searchValue = '%' . $fieldValue . '%';
							$query->bind($valueParam, $searchValue, ParameterType::STRING);
						}
						$query->where('EXISTS (' . (string) $subQuery . ')');
						$fieldIdParam = ':cf_field_id_' . $fieldId;
						$query->bind($fieldIdParam, $fieldId, ParameterType::INTEGER);
					}
				}
			}
		}

		$db->setQuery($query);

		try {
			return $db->loadObjectList() ?: [];
		} catch (\Exception $e) {
			return [];
		}
	}
}
